summaryrefslogtreecommitdiff
path: root/yaffs_packedtags2.c
diff options
context:
space:
mode:
authorCharles Manning <cdhmanning@gmail.com>2010-10-07 11:10:58 +1300
committerCharles Manning <cdhmanning@gmail.com>2010-10-07 11:14:38 +1300
commitf43976eda35065890e7cf0a008e9518158eb71d6 (patch)
treee19e6579100cf68632cb0981f277269e086c039e /yaffs_packedtags2.c
parent70c6bf2ff57c8a2fb778accdd5b4227abf273674 (diff)
yaffs Make more symbol changes
Signed-off-by: Charles Manning <cdhmanning@gmail.com>
Diffstat (limited to 'yaffs_packedtags2.c')
-rw-r--r--yaffs_packedtags2.c136
1 files changed, 68 insertions, 68 deletions
diff --git a/yaffs_packedtags2.c b/yaffs_packedtags2.c
index f8030c7..6b854cb 100644
--- a/yaffs_packedtags2.c
+++ b/yaffs_packedtags2.c
@@ -25,7 +25,7 @@
* This is defined by having the EXTRA_HEADER_INFO_FLAG set.
*/
/* Extra flags applied to chunkId */
#define EXTRA_HEADER_INFO_FLAG 0x80000000
#define EXTRA_SHRINK_FLAG 0x40000000
@@ -43,53 +43,53 @@ static void yaffs_DumpPackedTags2TagsPart(const yaffs_PackedTags2TagsPart *ptt)
{
T(YAFFS_TRACE_MTD,
(TSTR("packed tags obj %d chunk %d byte %d seq %d" TENDSTR),
- ptt->objectId, ptt->chunkId, ptt->byteCount,
- ptt->sequenceNumber));
+ ptt->obj_id, ptt->chunk_id, ptt->n_bytes,
+ ptt->seq_number));
}
static void yaffs_DumpPackedTags2(const yaffs_PackedTags2 *pt)
{
yaffs_DumpPackedTags2TagsPart(&pt->t);
}
-static void yaffs_DumpTags2(const yaffs_ExtendedTags *t)
+static void yaffs_DumpTags2(const yaffs_ext_tags *t)
{
T(YAFFS_TRACE_MTD,
(TSTR
("ext.tags eccres %d blkbad %d chused %d obj %d chunk%d byte %d del %d ser %d seq %d"
- TENDSTR), t->eccResult, t->blockBad, t->chunkUsed, t->objectId,
- t->chunkId, t->byteCount, t->chunkDeleted, t->serialNumber,
- t->sequenceNumber));
+ TENDSTR), t->ecc_result, t->block_bad, t->chunk_used, t->obj_id,
+ t->chunk_id, t->n_bytes, t->is_deleted, t->serial_number,
+ t->seq_number));
}
void yaffs_PackTags2TagsPart(yaffs_PackedTags2TagsPart *ptt,
- const yaffs_ExtendedTags *t)
+ const yaffs_ext_tags *t)
{
- ptt->chunkId = t->chunkId;
- ptt->sequenceNumber = t->sequenceNumber;
- ptt->byteCount = t->byteCount;
- ptt->objectId = t->objectId;
+ ptt->chunk_id = t->chunk_id;
+ ptt->seq_number = t->seq_number;
+ ptt->n_bytes = t->n_bytes;
+ ptt->obj_id = t->obj_id;
- if (t->chunkId == 0 && t->extraHeaderInfoAvailable) {
+ if (t->chunk_id == 0 && t->extra_available) {
/* Store the extra header info instead */
- /* We save the parent object in the chunkId */
- ptt->chunkId = EXTRA_HEADER_INFO_FLAG
- | t->extraParentObjectId;
- if (t->extraIsShrinkHeader)
- ptt->chunkId |= EXTRA_SHRINK_FLAG;
- if (t->extraShadows)
- ptt->chunkId |= EXTRA_SHADOWS_FLAG;
-
- ptt->objectId &= ~EXTRA_OBJECT_TYPE_MASK;
- ptt->objectId |=
- (t->extraObjectType << EXTRA_OBJECT_TYPE_SHIFT);
-
- if (t->extraObjectType == YAFFS_OBJECT_TYPE_HARDLINK)
- ptt->byteCount = t->extraEquivalentObjectId;
- else if (t->extraObjectType == YAFFS_OBJECT_TYPE_FILE)
- ptt->byteCount = t->extraFileLength;
+ /* We save the parent object in the chunk_id */
+ ptt->chunk_id = EXTRA_HEADER_INFO_FLAG
+ | t->extra_parent_id;
+ if (t->extra_is_shrink)
+ ptt->chunk_id |= EXTRA_SHRINK_FLAG;
+ if (t->extra_shadows)
+ ptt->chunk_id |= EXTRA_SHADOWS_FLAG;
+
+ ptt->obj_id &= ~EXTRA_OBJECT_TYPE_MASK;
+ ptt->obj_id |=
+ (t->extra_obj_type << EXTRA_OBJECT_TYPE_SHIFT);
+
+ if (t->extra_obj_type == YAFFS_OBJECT_TYPE_HARDLINK)
+ ptt->n_bytes = t->extra_equiv_id;
+ else if (t->extra_obj_type == YAFFS_OBJECT_TYPE_FILE)
+ ptt->n_bytes = t->extra_length;
else
- ptt->byteCount = 0;
+ ptt->n_bytes = 0;
}
yaffs_DumpPackedTags2TagsPart(ptt);
@@ -97,7 +97,7 @@ void yaffs_PackTags2TagsPart(yaffs_PackedTags2TagsPart *ptt,
}
-void yaffs_PackTags2(yaffs_PackedTags2 *pt, const yaffs_ExtendedTags *t, int tagsECC)
+void yaffs_PackTags2(yaffs_PackedTags2 *pt, const yaffs_ext_tags *t, int tagsECC)
{
yaffs_PackTags2TagsPart(&pt->t, t);
@@ -108,45 +108,45 @@ void yaffs_PackTags2(yaffs_PackedTags2 *pt, const yaffs_ExtendedTags *t, int tag
}
-void yaffs_unpack_tags2tags_part(yaffs_ExtendedTags *t,
+void yaffs_unpack_tags2tags_part(yaffs_ext_tags *t,
yaffs_PackedTags2TagsPart *ptt)
{
- memset(t, 0, sizeof(yaffs_ExtendedTags));
+ memset(t, 0, sizeof(yaffs_ext_tags));
yaffs_init_tags(t);
- if (ptt->sequenceNumber != 0xFFFFFFFF) {
- t->blockBad = 0;
- t->chunkUsed = 1;
- t->objectId = ptt->objectId;
- t->chunkId = ptt->chunkId;
- t->byteCount = ptt->byteCount;
- t->chunkDeleted = 0;
- t->serialNumber = 0;
- t->sequenceNumber = ptt->sequenceNumber;
+ if (ptt->seq_number != 0xFFFFFFFF) {
+ t->block_bad = 0;
+ t->chunk_used = 1;
+ t->obj_id = ptt->obj_id;
+ t->chunk_id = ptt->chunk_id;
+ t->n_bytes = ptt->n_bytes;
+ t->is_deleted = 0;
+ t->serial_number = 0;
+ t->seq_number = ptt->seq_number;
/* Do extra header info stuff */
- if (ptt->chunkId & EXTRA_HEADER_INFO_FLAG) {
- t->chunkId = 0;
- t->byteCount = 0;
-
- t->extraHeaderInfoAvailable = 1;
- t->extraParentObjectId =
- ptt->chunkId & (~(ALL_EXTRA_FLAGS));
- t->extraIsShrinkHeader =
- (ptt->chunkId & EXTRA_SHRINK_FLAG) ? 1 : 0;
- t->extraShadows =
- (ptt->chunkId & EXTRA_SHADOWS_FLAG) ? 1 : 0;
- t->extraObjectType =
- ptt->objectId >> EXTRA_OBJECT_TYPE_SHIFT;
- t->objectId &= ~EXTRA_OBJECT_TYPE_MASK;
-
- if (t->extraObjectType == YAFFS_OBJECT_TYPE_HARDLINK)
- t->extraEquivalentObjectId = ptt->byteCount;
+ if (ptt->chunk_id & EXTRA_HEADER_INFO_FLAG) {
+ t->chunk_id = 0;
+ t->n_bytes = 0;
+
+ t->extra_available = 1;
+ t->extra_parent_id =
+ ptt->chunk_id & (~(ALL_EXTRA_FLAGS));
+ t->extra_is_shrink =
+ (ptt->chunk_id & EXTRA_SHRINK_FLAG) ? 1 : 0;
+ t->extra_shadows =
+ (ptt->chunk_id & EXTRA_SHADOWS_FLAG) ? 1 : 0;
+ t->extra_obj_type =
+ ptt->obj_id >> EXTRA_OBJECT_TYPE_SHIFT;
+ t->obj_id &= ~EXTRA_OBJECT_TYPE_MASK;
+
+ if (t->extra_obj_type == YAFFS_OBJECT_TYPE_HARDLINK)
+ t->extra_equiv_id = ptt->n_bytes;
else
- t->extraFileLength = ptt->byteCount;
+ t->extra_length = ptt->n_bytes;
}
}
@@ -156,12 +156,12 @@ void yaffs_unpack_tags2tags_part(yaffs_ExtendedTags *t,
}
-void yaffs_unpack_tags2(yaffs_ExtendedTags *t, yaffs_PackedTags2 *pt, int tagsECC)
+void yaffs_unpack_tags2(yaffs_ext_tags *t, yaffs_PackedTags2 *pt, int tagsECC)
{
- yaffs_ECCResult eccResult = YAFFS_ECC_RESULT_NO_ERROR;
+ yaffs_ecc_result ecc_result = YAFFS_ECC_RESULT_NO_ERROR;
- if (pt->t.sequenceNumber != 0xFFFFFFFF &&
+ if (pt->t.seq_number != 0xFFFFFFFF &&
tagsECC){
/* Chunk is in use and we need to do ECC */
@@ -175,22 +175,22 @@ void yaffs_unpack_tags2(yaffs_ExtendedTags *t, yaffs_PackedTags2 *pt, int tagsEC
&pt->ecc, &ecc);
switch (result) {
case 0:
- eccResult = YAFFS_ECC_RESULT_NO_ERROR;
+ ecc_result = YAFFS_ECC_RESULT_NO_ERROR;
break;
case 1:
- eccResult = YAFFS_ECC_RESULT_FIXED;
+ ecc_result = YAFFS_ECC_RESULT_FIXED;
break;
case -1:
- eccResult = YAFFS_ECC_RESULT_UNFIXED;
+ ecc_result = YAFFS_ECC_RESULT_UNFIXED;
break;
default:
- eccResult = YAFFS_ECC_RESULT_UNKNOWN;
+ ecc_result = YAFFS_ECC_RESULT_UNKNOWN;
}
}
yaffs_unpack_tags2tags_part(t, &pt->t);
- t->eccResult = eccResult;
+ t->ecc_result = ecc_result;
yaffs_DumpPackedTags2(pt);
yaffs_DumpTags2(t);
@@ -25,7 +25,7 @@
* This is defined by having the EXTRA_HEADER_INFO_FLAG set.
*/
-/* Extra flags applied to chunkId */
+/* Extra flags applied to chunk_id */
#define EXTRA_HEADER_INFO_FLAG 0x80000000
#define EXTRA_SHRINK_FLAG 0x40000000